Crate scallion

Crate scallion 

scallion is a crate that is Quite Good at detecting licenses from text.

To get started, have a look at the Store struct, or one of the examples in the examples directory.

Structs

ContainedResult
A struct describing a single license identified within a larger text.
IdentifiedLicense
A struct describing a license that was identified, as well as its type.
LicenseEntry
Entry for a specific license in the license Store.
Match
Information about text that was compared against licenses in the store.
MatchData
A structure representing compiled text/matching data.
ScanResult
Information about scanned content.
ScanStrategy
A ScanStrategy can be used as a high-level wrapped over a Store’s analysis logic.
Store
A representation of a collection of known licenses.

Enums

CompressionFormat
License data cache compression format.
Error
SPDX license list cache handling error.
LicenseType
The type of a license entry (typically in a Store).
ScanMode
Available scanning strategy modes.